@@ -1,10 +1,11 @@
+import grpc
 import socket
 import os.path
 import sys
 
 from zsearch_definitions import search_pb2
 from zsearch_definitions import rpc_pb2
-from zsearch_definitions import hoststore_pb2 
+from zsearch_definitions import hoststore_pb2
 from zsearch_definitions.protocols import Protocol, Subprotocol
 
 class AdminService(object):
@@ -22,7 +23,8 @@ class AdminService(object):
     def __init__(self, host=None, port=None):
         host = host or self.HOST
         port = port or self.PORT
-        self._service = search_pb2.early_adopter_create_AdminService_stub(host, port).__enter__()
+        channel = grpc.insecure_channel('%s:%s' % (str(host), str(port)))
+        self._service = search_pb2.AdminServiceStub(channel)
 
     @property
     def service(self):
@@ -44,9 +46,25 @@ class AdminService(object):
             raise Exception("ZDB failure: %s" % retv.error)
         return retv
 
-    def dump_certificates(self, path, incremental=False, max_records=0):
-        retv = self._service.DumpCertificatesToJSON(rpc_pb2.Command(filepath=path,
-                incremental_dump=incremental, max_records=max_records), 4*60*60)
+    def validate_certificates(self, path):
+        retv = self._service.ValidateCertificates(rpc_pb2.Command(filepath=path),
+                 600*60*60)
+        if retv.status != rpc_pb2.CommandReply.SUCCESS:
+            raise Exception("ZDB failure: %s" % retv.error)
+        return retv
+
+    def regenerate_certificates(self):
+        retv = self._service.RegenerateCertificateDeltas(rpc_pb2.Command(), 10*60*60)
+        if retv.status != rpc_pb2.CommandReply.SUCCESS:
+            raise Exception("ZDB failure: %s" % retv.error)
+        return retv
+
+    def dump_certificates(self, path, incremental=False, max_records=0,
+            start_prefix=0, stop_prefix=0, num_threads=16):
+        cmd = rpc_pb2.Command(filepath=path, incremental_dump=False, 
+                 max_records=max_records, start_ip=start_prefix,
+                 stop_ip=stop_prefix, threads=num_threads)
+        retv = self._service.DumpCertificatesToJSON(cmd, 8*60*60)
         if retv.status != rpc_pb2.CommandReply.SUCCESS:
             raise Exception("ZDB failure: %s" % retv.error)
         return retv
@@ -58,7 +76,7 @@ class AdminService(object):
             cmd = rpc_pb2.Command()
         cmd.filepath = path
         cmd.max_records = max_records
-        retv = self._service.DumpIPv4ToJSON(cmd, 8*60*60)
+        retv = self._service.DumpIPv4ToJSON(cmd, 12*60*60)
         if retv.status != rpc_pb2.CommandReply.SUCCESS:
             raise Exception("ZDB failure: %s" % retv.error)
         return retv
@@ -110,8 +128,8 @@ class AdminService(object):
             raise Exception("ZDB failure: %s" % retv.error)
         return retv
 
-    def __del__(self):
-        if self._service:
-            self._service.__exit__(None, None, None)
+    #def __del__(self):
+    #    if self._service:
+    #        self._service.__exit__(None, None, None)
 
 
