@@ -8,6 +8,7 @@ import json
 import hashlib
 import struct
 import socket
+import grpc
 
 from zsearch_definitions import search_pb2
 from zsearch_definitions import protocols_pb2
@@ -54,26 +55,27 @@ class QueryService(object):
         return m.digest()
 
     def __init__(self, host=None, port=None):
-        port = port or self.PORT
         host = host or self.HOST
-        self._service = search_pb2.early_adopter_create_QueryService_stub(host,
-                port).__enter__()
+        port = port or self.PORT
+        channel = grpc.insecure_channel('%s:%s' % (str(host), str(port)))
+        self._service = search_pb2.QueryServiceStub(channel)
 
     @property
     def service(self):
         return self._service
 
     def get_certificate(self, sha256_fp):
+        sha256_fp = sha256_fp.decode("hex")
         aq = rpc_pb2.AnonymousQuery(
-                sha256fp=b64decode(sha256_fp))
-        res = self._service.GetCertificate(aq)
+                sha256fp=sha256_fp)
+        resp = self._service.GetCertificate(aq)
         assert(resp.status != self.AQ_RESERVED)
         if resp.status == self.AQ_ERROR:
             raise Exception("Request failed: %s" % resp.error)
         elif resp.status == self.AQ_NO_RECORD:
             return None
         else: # (SUCCESS)
-            return resp.certificate
+            return resp.record.certificate
 
 
     def put_certificate(self, raw, parsed):
@@ -92,6 +94,9 @@ class QueryService(object):
                 certificate=c
         )
         return self._service.UpsertCertificate(ar, self.TIMEOUT)
+    
+    def put_raw_certificate(self, rawcert):
+        return self._service.UpsertRawCertificate(rawcert, self.TIMEOUT)
 
 
     def _get_host_record(self, meth, ip, domain, port, proto, subproto):
@@ -181,13 +186,13 @@ class QueryService(object):
 
     def delete_host_domain_record(self, domain, port, proto, subproto):
         port = self._port_to_pb(port)
-        proto = protocols_pb2.Protocol.Value(proto)
-        subproto = protocols_pb2.Subprotocol.Value(subproto)
+        proto = zsearch_definitions.protocols.Protocol.from_pretty_name(proto)
+        subproto = zsearch_definitions.protocols.Subprotocol.from_pretty_name(subproto)
         host_query = rpc_pb2.HostQuery(
                         domain=domain,
                         port=port,
-                        proto=proto,
-                        subproto=subproto
+                        protocol=proto.value,
+                        subprotocol=subproto.value
                      )
         return self._service.DelHostDomainRecord(host_query, self.TIMEOUT)
 
@@ -213,10 +218,7 @@ class QueryService(object):
         for record in self.iter_host_records(self._service.GetAllDomainRecords, max_records):
             yield record
 
-    def __del__(self):
-        if self._service:
-            self._service.__exit__(None, None, None)
 
 if __name__ == "__main__":
    q = QueryService()
-   print q.get_host_ipv4_record(1046726718, 443, "https", "tls")
+   print q.get_certificate("bbf561e53fabf1a684d7cc1e890dab22ab0baabf73a1d85bb5063180424e9592")
